init_changes

Function init_changes 

pub fn init_changes(
    cwd: Option<String>,
    change_options: &Option<ChangesOptions>,
) -> ChangesFileData
Initialize the changes file. If the file does not exist, it will create it with the default message. If the file exists, it will return the content of the file.